==> feed_plugin-0.1.11.tar.gz: lib/widgets/videoB.dart <==
import 'package:chewie/chewie.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:video_player/video_player.dart';
import 'package:inview_notifier_list/inview_notifier_list.dart';

class VideoB extends StatefulWidget {
  // ignore: use_key_in_widget_constructors
  const VideoB(
      {Key key,
      @required this.url,
      @required this.play,
      this.title = 'Chewie Demo'})
      : super();

  final String url;
  final String title;
  final bool play;

  @override
  State<StatefulWidget> createState() {
    return _VideoBState();
  }
}

class _VideoBState extends State<VideoB> {
  TargetPlatform _platform;
  VideoPlayerController _videoPlayerController1;
  VideoPlayerController _videoPlayerController2;
  ChewieController _chewieController;

  @override
  void initState() {
    super.initState();
    initializePlayer();
  }

  @override
  void dispose() {
    _videoPlayerController1?.dispose();
    _videoPlayerController2?.dispose();
    _chewieController?.dispose();
    super.dispose();
  }

  Future<void> initializePlayer() async {
    _videoPlayerController1 = VideoPlayerController.network(this.widget.url);
    _videoPlayerController1.initialize().then((value) => {
          _chewieController = ChewieController(
            videoPlayerController: _videoPlayerController1,
            autoPlay: true,
            looping: true,
            autoInitialize: true,
            placeholder: Container(
              height: ScreenUtil().setHeight(570),
              padding: EdgeInsets.only(
                  top: ScreenUtil().setHeight(5),
                  bottom: ScreenUtil().setHeight(5)),
              color: Colors.grey[100],
            ),
            // showControls: false,
            // materialProgressColors: ChewieProgressColors(
            //   playedColor: Colors.red,
            //   handleColor: Colors.blue,
            //   backgroundColor: Colors.grey,
            //   bufferedColor: Colors.lightGreen,
            // ),
          )..setVolume(0.0),
          if (widget.play) {
            _chewieController.play(),
            _chewieController.setLooping(true)
          }
          else {
            _chewieController.pause()
          },
          setState(() {})
        });
  }

  //   @override
  // void didUpdateWidget(VideoB oldWidget) {
  //   if (oldWidget.play != widget.play) {
  //     if (widget.play) {
  //       _chewieController.play();
  //       _chewieController.setLooping(true);
  //     } else {
  //       _chewieController.pause();
  //     }
  //   }
  //   super.didUpdateWidget(oldWidget);
  // }

  @override
  Widget build(BuildContext context) {
    return Center(
      child: _chewieController != null &&
              _chewieController.videoPlayerController.value.initialized
          ? Chewie(
              controller: _chewieController,
            )
          : Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: const [
                CircularProgressIndicator(),
                SizedBox(height: 20),
                Text('Loading'),
              ],
            ),
    );
  }
}
// import 'package:flutter/material.dart';
// import 'package:video_player/video_player.dart';

// class VideoB extends StatefulWidget {
//   final String url;
//   final bool play;

//   const VideoB({Key key, @required this.url, @required this.play})
//       : super(key: key);
//   @override
//   _VideoBState createState() => _VideoBState();
// }

// class _VideoBState extends State<VideoB> {
//   VideoPlayerController _controller;
//   Future<void> _initializeVideoPlayerFuture;

//   @override
//   void initState() {
//     super.initState();
//     _controller = VideoPlayerController.network(widget.url);
//     _initializeVideoPlayerFuture = _controller.initialize().then((_) {
//       // Ensure the first frame is shown after the video is initialized, even before the play button has been pressed.
//       setState(() {});
//     });

//     if (widget.play) {
//       _controller.play();
//       _controller.setLooping(true);
//     }
//   }

//   @override
//   void didUpdateWidget(VideoB oldWidget) {
//     if (oldWidget.play != widget.play) {
//       if (widget.play) {
//         _controller.play();
//         _controller.setLooping(true);
//       } else {
//         _controller.pause();
//       }
//     }
//     super.didUpdateWidget(oldWidget);
//   }

//   @override
//   void dispose() {
//     _controller.dispose();
//     super.dispose();
//   }

//   @override
//   Widget build(BuildContext context) {
//     return FutureBuilder(
//       future: _initializeVideoPlayerFuture,
//       builder: (context, snapshot) {
//         if (snapshot.connectionState == ConnectionState.done) {
//           return VideoPlayer(_controller);
//         } else {
//           return Center(
//             child: CircularProgressIndicator(),
//           );
//         }
//       },
//     );
//   }
// }

==> feed_plugin-0.1.16.tar.gz: lib/widgets/videoB.dart <==
// import 'package:chewie/chewie.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:video_player/video_player.dart';
// import 'package:inview_notifier_list/inview_notifier_list.dart';

import 'chewie/chewie_player.dart';

class VideoB extends StatefulWidget {
  // ignore: use_key_in_widget_constructors
  const VideoB(
      {Key key,
      @required this.url,
      @required this.play,
      this.title = 'Chewie Demo'})
      : super();

  final String url;
  final String title;
  final bool play;

  @override
  State<StatefulWidget> createState() {
    return _VideoBState();
  }
}

class _VideoBState extends State<VideoB> {
  TargetPlatform _platform;
  VideoPlayerController _videoPlayerController1;
  VideoPlayerController _videoPlayerController2;
  ChewieController _chewieController;

  @override
  void initState() {
    super.initState();
    initializePlayer();
  }

  @override
  void dispose() {
    _videoPlayerController1?.dispose();
    _videoPlayerController2?.dispose();
    _chewieController?.dispose();
    super.dispose();
  }

  Future<void> initializePlayer() async {
    _videoPlayerController1 = VideoPlayerController.network(this.widget.url);
    _videoPlayerController1.initialize().then((value) => {
          _chewieController = ChewieController(
            videoPlayerController: _videoPlayerController1,
            autoPlay: true,
            looping: true,
            autoInitialize: true,
            placeholder: Container(
              height: ScreenUtil().setHeight(570),
              padding: EdgeInsets.only(
                  top: ScreenUtil().setHeight(5),
                  bottom: ScreenUtil().setHeight(5)),
              color: Colors.grey[100],
            ),
            // showControls: false,
            // materialProgressColors: ChewieProgressColors(
            //   playedColor: Colors.red,
            //   handleColor: Colors.blue,
            //   backgroundColor: Colors.grey,
            //   bufferedColor: Colors.lightGreen,
            // ),
          )..setVolume(0.0),
          if (widget.play) {
            _chewieController.play(),
            _chewieController.setLooping(true)
          }
          else {
            _chewieController.pause()
          },
          setState(() {})
        });
  }

  //   @override
  // void didUpdateWidget(VideoB oldWidget) {
  //   if (oldWidget.play != widget.play) {
  //     if (widget.play) {
  //       _chewieController.play();
  //       _chewieController.setLooping(true);
  //     } else {
  //       _chewieController.pause();
  //     }
  //   }
  //   super.didUpdateWidget(oldWidget);
  // }

  @override
  Widget build(BuildContext context) {
    return Center(
      child: _chewieController != null &&
              _chewieController.videoPlayerController.value.initialized
          ? Chewie(
              controller: _chewieController,
            )
          : Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: const [
                CircularProgressIndicator(),
                SizedBox(height: 20),
                Text('Loading'),
              ],
            ),
    );
  }
}
// import 'package:flutter/material.dart';
// import 'package:video_player/video_player.dart';

// class VideoB extends StatefulWidget {
//   final String url;
//   final bool play;

//   const VideoB({Key key, @required this.url, @required this.play})
//       : super(key: key);
//   @override
//   _VideoBState createState() => _VideoBState();
// }

// class _VideoBState extends State<VideoB> {
//   VideoPlayerController _controller;
//   Future<void> _initializeVideoPlayerFuture;

//   @override
//   void initState() {
//     super.initState();
//     _controller = VideoPlayerController.network(widget.url);
//     _initializeVideoPlayerFuture = _controller.initialize().then((_) {
//       // Ensure the first frame is shown after the video is initialized, even before the play button has been pressed.
//       setState(() {});
//     });

//     if (widget.play) {
//       _controller.play();
//       _controller.setLooping(true);
//     }
//   }

//   @override
//   void didUpdateWidget(VideoB oldWidget) {
//     if (oldWidget.play != widget.play) {
//       if (widget.play) {
//         _controller.play();
//         _controller.setLooping(true);
//       } else {
//         _controller.pause();
//       }
//     }
//     super.didUpdateWidget(oldWidget);
//   }

//   @override
//   void dispose() {
//     _controller.dispose();
//     super.dispose();
//   }

//   @override
//   Widget build(BuildContext context) {
//     return FutureBuilder(
//       future: _initializeVideoPlayerFuture,
//       builder: (context, snapshot) {
//         if (snapshot.connectionState == ConnectionState.done) {
//           return VideoPlayer(_controller);
//         } else {
//           return Center(
//             child: CircularProgressIndicator(),
//           );
//         }
//       },
//     );
//   }
// }
